# -*- coding: utf-8 -*-

"""
Form implementation generated from reading ui file 'interface_v1_2.ui'

Created by: PyQt5 UI code generator 5.14.1

WARNING! All changes made in this file will be lost!
"""

from PyQt5 import QtCore, QtGui, QtWidgets
from .icons_rc import *

class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        MainWindow.setObjectName("MainWindow")
        MainWindow.resize(1160, 665)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Maximum, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(MainWindow.sizePolicy().hasHeightForWidth())
        MainWindow.setSizePolicy(sizePolicy)
        self.centralwidget = QtWidgets.QWidget(MainWindow)
        self.centralwidget.setObjectName("centralwidget")
        self.verticalLayout = QtWidgets.QVBoxLayout(self.centralwidget)
        self.verticalLayout.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout.setSpacing(0)
        self.verticalLayout.setObjectName("verticalLayout")
        self.header_frame = QtWidgets.QFrame(self.centralwidget)
        self.header_frame.setStyleSheet("")
        self.header_frame.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.header_frame.setFrameShadow(QtWidgets.QFrame.Raised)
        self.header_frame.setObjectName("header_frame")
        self.horizontalLayout = QtWidgets.QHBoxLayout(self.header_frame)
        self.horizontalLayout.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout.setSpacing(0)
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.header_left_frame = QtWidgets.QFrame(self.header_frame)
        self.header_left_frame.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.header_left_frame.setFrameShadow(QtWidgets.QFrame.Raised)
        self.header_left_frame.setObjectName("header_left_frame")
        self.verticalLayout_2 = QtWidgets.QVBoxLayout(self.header_left_frame)
        self.verticalLayout_2.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_2.setSpacing(0)
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.horizontalLayout.addWidget(self.header_left_frame, 0, QtCore.Qt.AlignTop)
        self.header_center_frame = QtWidgets.QFrame(self.header_frame)
        self.header_center_frame.setStyleSheet("*{border:none;}")
        self.header_center_frame.setFrameShape(QtWidgets.QFrame.Panel)
        self.header_center_frame.setFrameShadow(QtWidgets.QFrame.Raised)
        self.header_center_frame.setObjectName("header_center_frame")
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout(self.header_center_frame)
        self.horizontalLayout_3.setContentsMargins(6, 6, 0, 6)
        self.horizontalLayout_3.setSpacing(0)
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        self.header_icon_label = QtWidgets.QLabel(self.header_center_frame)
        self.header_icon_label.setMaximumSize(QtCore.QSize(256, 16777215))
        self.header_icon_label.setText("")
        self.header_icon_label.setPixmap(QtGui.QPixmap(":/icons/icon_signal.svg"))
        self.header_icon_label.setObjectName("header_icon_label")
        self.horizontalLayout_3.addWidget(self.header_icon_label)
        self.header_title_label = QtWidgets.QLabel(self.header_center_frame)
        font = QtGui.QFont()
        font.setPointSize(12)
        font.setBold(True)
        font.setWeight(75)
        self.header_title_label.setFont(font)
        self.header_title_label.setObjectName("header_title_label")
        self.horizontalLayout_3.addWidget(self.header_title_label, 0, QtCore.Qt.AlignRight|QtCore.Qt.AlignTop)
        spacerItem = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_3.addItem(spacerItem)
        self.horizontalLayout.addWidget(self.header_center_frame, 0, QtCore.Qt.AlignTop)
        self.header_right_frame = QtWidgets.QFrame(self.header_frame)
        self.header_right_frame.setMinimumSize(QtCore.QSize(0, 0))
        self.header_right_frame.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.header_right_frame.setFrameShadow(QtWidgets.QFrame.Raised)
        self.header_right_frame.setObjectName("header_right_frame")
        self.verticalLayout_10 = QtWidgets.QVBoxLayout(self.header_right_frame)
        self.verticalLayout_10.setContentsMargins(0, 0, 6, 0)
        self.verticalLayout_10.setSpacing(9)
        self.verticalLayout_10.setObjectName("verticalLayout_10")
        self.robot_camera_button = QtWidgets.QPushButton(self.header_right_frame)
        self.robot_camera_button.setStyleSheet("background-color: rgb(6, 37, 98);\n"
"color: rgb(255, 255, 255);")
        self.robot_camera_button.setObjectName("robot_camera_button")
        self.verticalLayout_10.addWidget(self.robot_camera_button)
        self.horizontalLayout.addWidget(self.header_right_frame, 0, QtCore.Qt.AlignRight|QtCore.Qt.AlignVCenter)
        self.verticalLayout.addWidget(self.header_frame)
        self.main_body_frame = QtWidgets.QFrame(self.centralwidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.main_body_frame.sizePolicy().hasHeightForWidth())
        self.main_body_frame.setSizePolicy(sizePolicy)
        self.main_body_frame.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.main_body_frame.setFrameShadow(QtWidgets.QFrame.Raised)
        self.main_body_frame.setObjectName("main_body_frame")
        self.horizontalLayout_7 = QtWidgets.QHBoxLayout(self.main_body_frame)
        self.horizontalLayout_7.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_7.setSpacing(0)
        self.horizontalLayout_7.setObjectName("horizontalLayout_7")
        self.left_body_cont_frame = QtWidgets.QFrame(self.main_body_frame)
        self.left_body_cont_frame.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.left_body_cont_frame.setFrameShadow(QtWidgets.QFrame.Raised)
        self.left_body_cont_frame.setObjectName("left_body_cont_frame")
        self.verticalLayout_3 = QtWidgets.QVBoxLayout(self.left_body_cont_frame)
        self.verticalLayout_3.setContentsMargins(9, 0, 0, 0)
        self.verticalLayout_3.setSpacing(0)
        self.verticalLayout_3.setObjectName("verticalLayout_3")
        self.left_upper_frame = QtWidgets.QFrame(self.left_body_cont_frame)
        self.left_upper_frame.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.left_upper_frame.setFrameShadow(QtWidgets.QFrame.Raised)
        self.left_upper_frame.setObjectName("left_upper_frame")
        self.verticalLayout_4 = QtWidgets.QVBoxLayout(self.left_upper_frame)
        self.verticalLayout_4.setContentsMargins(0, 0, 10, 0)
        self.verticalLayout_4.setSpacing(0)
        self.verticalLayout_4.setObjectName("verticalLayout_4")
        self.image_file_frame = QtWidgets.QFrame(self.left_upper_frame)
        self.image_file_frame.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.image_file_frame.setFrameShadow(QtWidgets.QFrame.Raised)
        self.image_file_frame.setObjectName("image_file_frame")
        self.horizontalLayout_9 = QtWidgets.QHBoxLayout(self.image_file_frame)
        self.horizontalLayout_9.setObjectName("horizontalLayout_9")
        self.image_file_label = QtWidgets.QLabel(self.image_file_frame)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.image_file_label.setFont(font)
        self.image_file_label.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.image_file_label.setObjectName("image_file_label")
        self.horizontalLayout_9.addWidget(self.image_file_label)
        self.verticalLayout_4.addWidget(self.image_file_frame)
        self.image_file_tree = QtWidgets.QTreeView(self.left_upper_frame)
        self.image_file_tree.setObjectName("image_file_tree")
        self.verticalLayout_4.addWidget(self.image_file_tree)
        self.fi_file_frame = QtWidgets.QFrame(self.left_upper_frame)
        self.fi_file_frame.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.fi_file_frame.setFrameShadow(QtWidgets.QFrame.Raised)
        self.fi_file_frame.setObjectName("fi_file_frame")
        self.horizontalLayout_11 = QtWidgets.QHBoxLayout(self.fi_file_frame)
        self.horizontalLayout_11.setObjectName("horizontalLayout_11")
        self.fi_file_label = QtWidgets.QLabel(self.fi_file_frame)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.fi_file_label.setFont(font)
        self.fi_file_label.setObjectName("fi_file_label")
        self.horizontalLayout_11.addWidget(self.fi_file_label)
        self.verticalLayout_4.addWidget(self.fi_file_frame)
        self.fi_file_tree = QtWidgets.QTreeView(self.left_upper_frame)
        self.fi_file_tree.setObjectName("fi_file_tree")
        self.verticalLayout_4.addWidget(self.fi_file_tree)
        self.verticalLayout_3.addWidget(self.left_upper_frame)
        self.left_bottom_frame = QtWidgets.QFrame(self.left_body_cont_frame)
        self.left_bottom_frame.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.left_bottom_frame.setFrameShadow(QtWidgets.QFrame.Raised)
        self.left_bottom_frame.setObjectName("left_bottom_frame")
        self.horizontalLayout_8 = QtWidgets.QHBoxLayout(self.left_bottom_frame)
        self.horizontalLayout_8.setContentsMargins(0, 6, 10, 6)
        self.horizontalLayout_8.setSpacing(0)
        self.horizontalLayout_8.setObjectName("horizontalLayout_8")
        self.find_image_file_button = QtWidgets.QPushButton(self.left_bottom_frame)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.find_image_file_button.sizePolicy().hasHeightForWidth())
        self.find_image_file_button.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.find_image_file_button.setFont(font)
        self.find_image_file_button.setStyleSheet("")
        self.find_image_file_button.setObjectName("find_image_file_button")
        self.horizontalLayout_8.addWidget(self.find_image_file_button)
        spacerItem1 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_8.addItem(spacerItem1)
        self.find_fi_file_button = QtWidgets.QPushButton(self.left_bottom_frame)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.find_fi_file_button.sizePolicy().hasHeightForWidth())
        self.find_fi_file_button.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.find_fi_file_button.setFont(font)
        self.find_fi_file_button.setObjectName("find_fi_file_button")
        self.horizontalLayout_8.addWidget(self.find_fi_file_button)
        self.verticalLayout_3.addWidget(self.left_bottom_frame)
        self.horizontalLayout_7.addWidget(self.left_body_cont_frame)
        self.center_body_cont_frame = QtWidgets.QFrame(self.main_body_frame)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.center_body_cont_frame.sizePolicy().hasHeightForWidth())
        self.center_body_cont_frame.setSizePolicy(sizePolicy)
        self.center_body_cont_frame.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.center_body_cont_frame.setFrameShadow(QtWidgets.QFrame.Raised)
        self.center_body_cont_frame.setObjectName("center_body_cont_frame")
        self.verticalLayout_5 = QtWidgets.QVBoxLayout(self.center_body_cont_frame)
        self.verticalLayout_5.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_5.setObjectName("verticalLayout_5")
        self.central_menu_label_frame = QtWidgets.QFrame(self.center_body_cont_frame)
        self.central_menu_label_frame.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.central_menu_label_frame.setFrameShadow(QtWidgets.QFrame.Raised)
        self.central_menu_label_frame.setObjectName("central_menu_label_frame")
        self.verticalLayout_6 = QtWidgets.QVBoxLayout(self.central_menu_label_frame)
        self.verticalLayout_6.setObjectName("verticalLayout_6")
        self.central_menu_label = QtWidgets.QLabel(self.central_menu_label_frame)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.central_menu_label.setFont(font)
        self.central_menu_label.setObjectName("central_menu_label")
        self.verticalLayout_6.addWidget(self.central_menu_label)
        self.verticalLayout_5.addWidget(self.central_menu_label_frame, 0, QtCore.Qt.AlignTop)
        self.central_menu_frame = QtWidgets.QFrame(self.center_body_cont_frame)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.central_menu_frame.sizePolicy().hasHeightForWidth())
        self.central_menu_frame.setSizePolicy(sizePolicy)
        self.central_menu_frame.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.central_menu_frame.setFrameShadow(QtWidgets.QFrame.Raised)
        self.central_menu_frame.setObjectName("central_menu_frame")
        self.gridLayout = QtWidgets.QGridLayout(self.central_menu_frame)
        self.gridLayout.setContentsMargins(6, 0, 10, 0)
        self.gridLayout.setSpacing(0)
        self.gridLayout.setObjectName("gridLayout")
        self.fault_rate_frame = QtWidgets.QFrame(self.central_menu_frame)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Maximum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.fault_rate_frame.sizePolicy().hasHeightForWidth())
        self.fault_rate_frame.setSizePolicy(sizePolicy)
        self.fault_rate_frame.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.fault_rate_frame.setFrameShadow(QtWidgets.QFrame.Raised)
        self.fault_rate_frame.setObjectName("fault_rate_frame")
        self.horizontalLayout_10 = QtWidgets.QHBoxLayout(self.fault_rate_frame)
        self.horizontalLayout_10.setObjectName("horizontalLayout_10")
        self.fault_rate_slider = QtWidgets.QSlider(self.fault_rate_frame)
        self.fault_rate_slider.setOrientation(QtCore.Qt.Horizontal)
        self.fault_rate_slider.setObjectName("fault_rate_slider")
        self.horizontalLayout_10.addWidget(self.fault_rate_slider)
        self.fault_rate_textbrowser = QtWidgets.QTextBrowser(self.fault_rate_frame)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Maximum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.fault_rate_textbrowser.sizePolicy().hasHeightForWidth())
        self.fault_rate_textbrowser.setSizePolicy(sizePolicy)
        self.fault_rate_textbrowser.setMaximumSize(QtCore.QSize(64, 32))
        self.fault_rate_textbrowser.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.fault_rate_textbrowser.setObjectName("fault_rate_textbrowser")
        self.horizontalLayout_10.addWidget(self.fault_rate_textbrowser)
        self.gridLayout.addWidget(self.fault_rate_frame, 6, 3, 1, 1)
        self.fault_rate_label = QtWidgets.QLabel(self.central_menu_frame)
        self.fault_rate_label.setObjectName("fault_rate_label")
        self.gridLayout.addWidget(self.fault_rate_label, 6, 1, 1, 1)
        self.camera_type_label = QtWidgets.QLabel(self.central_menu_frame)
        self.camera_type_label.setObjectName("camera_type_label")
        self.gridLayout.addWidget(self.camera_type_label, 2, 1, 1, 1)
        self.ros_cam_topic_label = QtWidgets.QLabel(self.central_menu_frame)
        self.ros_cam_topic_label.setEnabled(False)
        font = QtGui.QFont()
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.ros_cam_topic_label.setFont(font)
        self.ros_cam_topic_label.setText("")
        self.ros_cam_topic_label.setObjectName("ros_cam_topic_label")
        self.gridLayout.addWidget(self.ros_cam_topic_label, 8, 1, 1, 1)
        self.fault_type_combobox = QtWidgets.QComboBox(self.central_menu_frame)
        self.fault_type_combobox.setObjectName("fault_type_combobox")
        self.gridLayout.addWidget(self.fault_type_combobox, 5, 3, 1, 1)
        self.fault_type_label = QtWidgets.QLabel(self.central_menu_frame)
        self.fault_type_label.setObjectName("fault_type_label")
        self.gridLayout.addWidget(self.fault_type_label, 5, 1, 1, 1)
        self.robot_camera_label = QtWidgets.QLabel(self.central_menu_frame)
        self.robot_camera_label.setObjectName("robot_camera_label")
        self.gridLayout.addWidget(self.robot_camera_label, 7, 1, 1, 1)
        self.camera_type_combobox = QtWidgets.QComboBox(self.central_menu_frame)
        self.camera_type_combobox.setObjectName("camera_type_combobox")
        self.gridLayout.addWidget(self.camera_type_combobox, 2, 3, 1, 1)
        self.robot_camera_combobox = QtWidgets.QComboBox(self.central_menu_frame)
        self.robot_camera_combobox.setObjectName("robot_camera_combobox")
        self.gridLayout.addWidget(self.robot_camera_combobox, 7, 3, 1, 1)
        self.ros_cam_topic_text = QtWidgets.QTextEdit(self.central_menu_frame)
        self.ros_cam_topic_text.setEnabled(False)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.ros_cam_topic_text.sizePolicy().hasHeightForWidth())
        self.ros_cam_topic_text.setSizePolicy(sizePolicy)
        self.ros_cam_topic_text.setMaximumSize(QtCore.QSize(16777215, 32))
        self.ros_cam_topic_text.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.ros_cam_topic_text.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.ros_cam_topic_text.setObjectName("ros_cam_topic_text")
        self.gridLayout.addWidget(self.ros_cam_topic_text, 8, 3, 1, 1)
        self.ros_cam_fi_freq_label = QtWidgets.QLabel(self.central_menu_frame)
        self.ros_cam_fi_freq_label.setEnabled(False)
        font = QtGui.QFont()
        font.setPointSize(10)
        font.setBold(True)
        font.setWeight(75)
        self.ros_cam_fi_freq_label.setFont(font)
        self.ros_cam_fi_freq_label.setText("")
        self.ros_cam_fi_freq_label.setObjectName("ros_cam_fi_freq_label")
        self.gridLayout.addWidget(self.ros_cam_fi_freq_label, 9, 1, 1, 1)
        self.ros_cam_fi_freq_text = QtWidgets.QTextEdit(self.central_menu_frame)
        self.ros_cam_fi_freq_text.setEnabled(False)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.ros_cam_fi_freq_text.sizePolicy().hasHeightForWidth())
        self.ros_cam_fi_freq_text.setSizePolicy(sizePolicy)
        self.ros_cam_fi_freq_text.setMaximumSize(QtCore.QSize(16777215, 32))
        self.ros_cam_fi_freq_text.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.ros_cam_fi_freq_text.setReadOnly(True)
        self.ros_cam_fi_freq_text.setObjectName("ros_cam_fi_freq_text")
        self.gridLayout.addWidget(self.ros_cam_fi_freq_text, 9, 3, 1, 1)
        self.fi_type_label = QtWidgets.QLabel(self.central_menu_frame)
        self.fi_type_label.setObjectName("fi_type_label")
        self.gridLayout.addWidget(self.fi_type_label, 0, 1, 1, 1)
        self.fi_type_combobox = QtWidgets.QComboBox(self.central_menu_frame)
        self.fi_type_combobox.setObjectName("fi_type_combobox")
        self.gridLayout.addWidget(self.fi_type_combobox, 0, 3, 1, 1)
        self.verticalLayout_5.addWidget(self.central_menu_frame)
        self.horizontalLayout_7.addWidget(self.center_body_cont_frame)
        self.right_body_cont_frame = QtWidgets.QFrame(self.main_body_frame)
        self.right_body_cont_frame.setStyleSheet("")
        self.right_body_cont_frame.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.right_body_cont_frame.setFrameShadow(QtWidgets.QFrame.Raised)
        self.right_body_cont_frame.setObjectName("right_body_cont_frame")
        self.gridLayout_3 = QtWidgets.QGridLayout(self.right_body_cont_frame)
        self.gridLayout_3.setContentsMargins(0, 0, 9, 0)
        self.gridLayout_3.setObjectName("gridLayout_3")
        self.right_bottom_frame = QtWidgets.QFrame(self.right_body_cont_frame)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.right_bottom_frame.sizePolicy().hasHeightForWidth())
        self.right_bottom_frame.setSizePolicy(sizePolicy)
        self.right_bottom_frame.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.right_bottom_frame.setFrameShadow(QtWidgets.QFrame.Raised)
        self.right_bottom_frame.setObjectName("right_bottom_frame")
        self.gridLayout_2 = QtWidgets.QGridLayout(self.right_bottom_frame)
        self.gridLayout_2.setContentsMargins(0, 20, 0, 20)
        self.gridLayout_2.setObjectName("gridLayout_2")
        self.show_fi_plan_details_button = QtWidgets.QPushButton(self.right_bottom_frame)
        font = QtGui.QFont()
        font.setPointSize(11)
        font.setBold(False)
        font.setWeight(50)
        self.show_fi_plan_details_button.setFont(font)
        self.show_fi_plan_details_button.setStyleSheet("background-color: rgb(6, 37, 98);\n"
"color: rgb(255, 255, 255);")
        self.show_fi_plan_details_button.setObjectName("show_fi_plan_details_button")
        self.gridLayout_2.addWidget(self.show_fi_plan_details_button, 4, 2, 1, 1)
        self.save_fi_plan_button = QtWidgets.QPushButton(self.right_bottom_frame)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Maximum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.save_fi_plan_button.sizePolicy().hasHeightForWidth())
        self.save_fi_plan_button.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setPointSize(11)
        font.setBold(False)
        font.setWeight(50)
        self.save_fi_plan_button.setFont(font)
        self.save_fi_plan_button.setStyleSheet("background-color: rgb(6, 37, 98);\n"
"color: rgb(255, 255, 255);")
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(":/icons/cil-save.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.save_fi_plan_button.setIcon(icon)
        self.save_fi_plan_button.setObjectName("save_fi_plan_button")
        self.gridLayout_2.addWidget(self.save_fi_plan_button, 3, 2, 1, 1)
        self.apply_fault_button = QtWidgets.QPushButton(self.right_bottom_frame)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Maximum, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.apply_fault_button.sizePolicy().hasHeightForWidth())
        self.apply_fault_button.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setBold(False)
        font.setWeight(50)
        self.apply_fault_button.setFont(font)
        self.apply_fault_button.setStyleSheet("background-color: rgb(6, 37, 98);\n"
"color: rgb(255, 255, 255);")
        icon1 = QtGui.QIcon()
        icon1.addPixmap(QtGui.QPixmap(":/icons/cil-cloud-upload.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.apply_fault_button.setIcon(icon1)
        self.apply_fault_button.setObjectName("apply_fault_button")
        self.gridLayout_2.addWidget(self.apply_fault_button, 4, 0, 1, 1)
        self.randomize_check = QtWidgets.QCheckBox(self.right_bottom_frame)
        self.randomize_check.setObjectName("randomize_check")
        self.gridLayout_2.addWidget(self.randomize_check, 3, 0, 1, 1)
        self.gridLayout_3.addWidget(self.right_bottom_frame, 2, 0, 1, 1)
        self.right_upper_frame = QtWidgets.QFrame(self.right_body_cont_frame)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.right_upper_frame.sizePolicy().hasHeightForWidth())
        self.right_upper_frame.setSizePolicy(sizePolicy)
        self.right_upper_frame.setMinimumSize(QtCore.QSize(0, 0))
        self.right_upper_frame.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.right_upper_frame.setFrameShadow(QtWidgets.QFrame.Raised)
        self.right_upper_frame.setObjectName("right_upper_frame")
        self.verticalLayout_7 = QtWidgets.QVBoxLayout(self.right_upper_frame)
        self.verticalLayout_7.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_7.setSpacing(0)
        self.verticalLayout_7.setObjectName("verticalLayout_7")
        self.info_frame = QtWidgets.QFrame(self.right_upper_frame)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.info_frame.sizePolicy().hasHeightForWidth())
        self.info_frame.setSizePolicy(sizePolicy)
        self.info_frame.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.info_frame.setFrameShadow(QtWidgets.QFrame.Raised)
        self.info_frame.setObjectName("info_frame")
        self.verticalLayout_8 = QtWidgets.QVBoxLayout(self.info_frame)
        self.verticalLayout_8.setContentsMargins(0, 0, 0, 0)
        self.verticalLayout_8.setSpacing(0)
        self.verticalLayout_8.setObjectName("verticalLayout_8")
        self.info_label_frame = QtWidgets.QFrame(self.info_frame)
        self.info_label_frame.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.info_label_frame.setFrameShadow(QtWidgets.QFrame.Raised)
        self.info_label_frame.setObjectName("info_label_frame")
        self.horizontalLayout_13 = QtWidgets.QHBoxLayout(self.info_label_frame)
        self.horizontalLayout_13.setObjectName("horizontalLayout_13")
        self.info_label = QtWidgets.QLabel(self.info_label_frame)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.info_label.setFont(font)
        self.info_label.setStyleSheet("*{border:none;}")
        self.info_label.setObjectName("info_label")
        self.horizontalLayout_13.addWidget(self.info_label)
        self.verticalLayout_8.addWidget(self.info_label_frame)
        self.verticalLayout_7.addWidget(self.info_frame)
        self.info_text = QtWidgets.QTextEdit(self.right_upper_frame)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.info_text.sizePolicy().hasHeightForWidth())
        self.info_text.setSizePolicy(sizePolicy)
        self.info_text.setMinimumSize(QtCore.QSize(0, 150))
        self.info_text.setMaximumSize(QtCore.QSize(16777215, 250))
        self.info_text.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.info_text.setReadOnly(True)
        self.info_text.setObjectName("info_text")
        self.verticalLayout_7.addWidget(self.info_text)
        self.fi_plan_frame = QtWidgets.QFrame(self.right_upper_frame)
        self.fi_plan_frame.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.fi_plan_frame.setFrameShadow(QtWidgets.QFrame.Raised)
        self.fi_plan_frame.setObjectName("fi_plan_frame")
        self.horizontalLayout_12 = QtWidgets.QHBoxLayout(self.fi_plan_frame)
        self.horizontalLayout_12.setObjectName("horizontalLayout_12")
        self.fi_plan_label = QtWidgets.QLabel(self.fi_plan_frame)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.fi_plan_label.setFont(font)
        self.fi_plan_label.setObjectName("fi_plan_label")
        self.horizontalLayout_12.addWidget(self.fi_plan_label)
        self.verticalLayout_7.addWidget(self.fi_plan_frame)
        self.fi_plan_tree = QtWidgets.QTreeView(self.right_upper_frame)
        self.fi_plan_tree.setObjectName("fi_plan_tree")
        self.verticalLayout_7.addWidget(self.fi_plan_tree)
        self.gridLayout_3.addWidget(self.right_upper_frame, 0, 0, 1, 1)
        self.progressBar_frame = QtWidgets.QFrame(self.right_body_cont_frame)
        self.progressBar_frame.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.progressBar_frame.setFrameShadow(QtWidgets.QFrame.Raised)
        self.progressBar_frame.setObjectName("progressBar_frame")
        self.verticalLayout_9 = QtWidgets.QVBoxLayout(self.progressBar_frame)
        self.verticalLayout_9.setObjectName("verticalLayout_9")
        self.progressBar_label = QtWidgets.QLabel(self.progressBar_frame)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.progressBar_label.setFont(font)
        self.progressBar_label.setObjectName("progressBar_label")
        self.verticalLayout_9.addWidget(self.progressBar_label)
        self.progressBar = QtWidgets.QProgressBar(self.progressBar_frame)
        self.progressBar.setStyleSheet("    border: 2px solid #2196F3;\n"
"    border-radius: 5px;\n"
"    background-color: #E0E0E0;")
        self.progressBar.setProperty("value", 24)
        self.progressBar.setAlignment(QtCore.Qt.AlignCenter)
        self.progressBar.setFormat("")
        self.progressBar.setObjectName("progressBar")
        self.verticalLayout_9.addWidget(self.progressBar)
        self.gridLayout_3.addWidget(self.progressBar_frame, 1, 0, 1, 1)
        self.horizontalLayout_7.addWidget(self.right_body_cont_frame)
        self.verticalLayout.addWidget(self.main_body_frame)
        self.footer_frame = QtWidgets.QFrame(self.centralwidget)
        self.footer_frame.setFrameShape(QtWidgets.QFrame.StyledPanel)
        self.footer_frame.setFrameShadow(QtWidgets.QFrame.Raised)
        self.footer_frame.setObjectName("footer_frame")
        self.horizontalLayout_6 = QtWidgets.QHBoxLayout(self.footer_frame)
        self.horizontalLayout_6.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_6.setSpacing(0)
        self.horizontalLayout_6.setObjectName("horizontalLayout_6")
        self.footer_left_frame = QtWidgets.QFrame(self.footer_frame)
        self.footer_left_frame.setStyleSheet("*{border:none;}")
        self.footer_left_frame.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.footer_left_frame.setFrameShadow(QtWidgets.QFrame.Raised)
        self.footer_left_frame.setObjectName("footer_left_frame")
        self.horizontalLayout_4 = QtWidgets.QHBoxLayout(self.footer_left_frame)
        self.horizontalLayout_4.setObjectName("horizontalLayout_4")
        self.version_info_label = QtWidgets.QLabel(self.footer_left_frame)
        self.version_info_label.setObjectName("version_info_label")
        self.horizontalLayout_4.addWidget(self.version_info_label, 0, QtCore.Qt.AlignLeft)
        self.horizontalLayout_6.addWidget(self.footer_left_frame)
        self.footer_info_frame = QtWidgets.QFrame(self.footer_frame)
        self.footer_info_frame.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.footer_info_frame.setFrameShadow(QtWidgets.QFrame.Raised)
        self.footer_info_frame.setObjectName("footer_info_frame")
        self.horizontalLayout_14 = QtWidgets.QHBoxLayout(self.footer_info_frame)
        self.horizontalLayout_14.setObjectName("horizontalLayout_14")
        self.footer_info_label = QtWidgets.QLabel(self.footer_info_frame)
        self.footer_info_label.setText("")
        self.footer_info_label.setObjectName("footer_info_label")
        self.horizontalLayout_14.addWidget(self.footer_info_label)
        self.horizontalLayout_6.addWidget(self.footer_info_frame, 0, QtCore.Qt.AlignHCenter)
        self.footer_right_frame = QtWidgets.QFrame(self.footer_frame)
        self.footer_right_frame.setStyleSheet("")
        self.footer_right_frame.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.footer_right_frame.setFrameShadow(QtWidgets.QFrame.Raised)
        self.footer_right_frame.setObjectName("footer_right_frame")
        self.horizontalLayout_5 = QtWidgets.QHBoxLayout(self.footer_right_frame)
        self.horizontalLayout_5.setObjectName("horizontalLayout_5")
        self.about_button = QtWidgets.QPushButton(self.footer_right_frame)
        self.about_button.setStyleSheet("background-color: rgb(6, 37, 98);\n"
"color: rgb(255, 255, 255);")
        self.about_button.setObjectName("about_button")
        self.horizontalLayout_5.addWidget(self.about_button, 0, QtCore.Qt.AlignRight)
        self.help_button = QtWidgets.QPushButton(self.footer_right_frame)
        self.help_button.setStyleSheet("background-color: rgb(6, 37, 98);\n"
"color: rgb(255, 255, 255);")
        self.help_button.setObjectName("help_button")
        self.horizontalLayout_5.addWidget(self.help_button)
        self.horizontalLayout_6.addWidget(self.footer_right_frame, 0, QtCore.Qt.AlignRight)
        self.size_grip = QtWidgets.QFrame(self.footer_frame)
        self.size_grip.setMaximumSize(QtCore.QSize(10, 10))
        self.size_grip.setFrameShape(QtWidgets.QFrame.NoFrame)
        self.size_grip.setFrameShadow(QtWidgets.QFrame.Raised)
        self.size_grip.setObjectName("size_grip")
        self.horizontalLayout_6.addWidget(self.size_grip, 0, QtCore.Qt.AlignBottom)
        self.verticalLayout.addWidget(self.footer_frame, 0, QtCore.Qt.AlignBottom)
        MainWindow.setCentralWidget(self.centralwidget)

        self.retranslateUi(MainWindow)
        QtCore.QMetaObject.connectSlotsByName(MainWindow)

    def retranslateUi(self, MainWindow):
        _translate = QtCore.QCoreApplication.translate
        MainWindow.setWindowTitle(_translate("MainWindow", "MainWindow"))
        self.header_title_label.setText(_translate("MainWindow", "  Camera Fault Injection Tool"))
        self.robot_camera_button.setText(_translate("MainWindow", "Robot Cam"))
        self.image_file_label.setText(_translate("MainWindow", "Normal Image Folders"))
        self.fi_file_label.setText(_translate("MainWindow", "FI Image Folders"))
        self.find_image_file_button.setText(_translate("MainWindow", "Select Image Folder"))
        self.find_fi_file_button.setText(_translate("MainWindow", "Select FI Image Folder"))
        self.central_menu_label.setText(_translate("MainWindow", "Camera Fault Configuration"))
        self.fault_rate_label.setText(_translate("MainWindow", "Fault Rate (%)"))
        self.camera_type_label.setText(_translate("MainWindow", "Camera Type"))
        self.fault_type_label.setText(_translate("MainWindow", "Fault Type"))
        self.robot_camera_label.setText(_translate("MainWindow", "Robot Camera"))
        self.ros_cam_topic_text.setHtml(_translate("MainWindow", "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:\'Ubuntu\'; font-size:11pt; font-weight:400; font-style:normal;\">\n"
"<p style=\"-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><br /></p></body></html>"))
        self.ros_cam_fi_freq_text.setHtml(_translate("MainWindow", "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:\'Ubuntu\'; font-size:11pt; font-weight:400; font-style:normal;\">\n"
"<p style=\"-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><br /></p></body></html>"))
        self.fi_type_label.setText(_translate("MainWindow", "Fault Injection Type   "))
        self.show_fi_plan_details_button.setText(_translate("MainWindow", "Show FIP Details"))
        self.save_fi_plan_button.setText(_translate("MainWindow", "  Save FI Plan  "))
        self.apply_fault_button.setText(_translate("MainWindow", "Apply Fault"))
        self.randomize_check.setText(_translate("MainWindow", "Randomize"))
        self.info_label.setText(_translate("MainWindow", "Info"))
        self.fi_plan_label.setText(_translate("MainWindow", "FI Plans"))
        self.progressBar_label.setText(_translate("MainWindow", "FI Applying Progress"))
        self.version_info_label.setText(_translate("MainWindow", "Version 1.2.3"))
        self.about_button.setText(_translate("MainWindow", "About"))
        self.help_button.setText(_translate("MainWindow", "Help"))
